==> haskell-http-client-tls-0.3.5.3-109-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.3
id: http-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
key: http-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
abi: f4dfa4b7364fc48a8f0ef6188de47175
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-tls-0.3.5.3
hs-libraries: HShttp-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    connection-0.2.8-60CoESWDtkP8GOtdZUw1hW containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    http-client-0.6.4-DCmpgbT5KA3LBdEx9Lt28S
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK text-1.2.3.1
    tls-1.4.1-FpL0z7KZJreH7VtfsMhlVP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.5.3-110-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.3
id: http-client-tls-0.3.5.3-FGEtAJdllnfFFv117grufi
key: http-client-tls-0.3.5.3-FGEtAJdllnfFFv117grufi
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
abi: 6c83e43d4f76e30c2d1bf85c69404dfe
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-tls-0.3.5.3
hs-libraries: HShttp-client-tls-0.3.5.3-FGEtAJdllnfFFv117grufi
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    connection-0.2.8-60CoESWDtkP8GOtdZUw1hW containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    http-client-0.6.4-Cv7r4OJjM9k1hDatz0YNuk
    http-types-0.12.3-9p0mDzXduAV3s3QD76BvaS
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK text-1.2.3.1
    tls-1.4.1-FpL0z7KZJreH7VtfsMhlVP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
